final def isWindows = (System.getProperty('os.name') =~ /(?i)windows/).find()
out = System.out;
def wsadmin = isWindows ? "wsadmin.bat" : "wsadmin.sh"

final def workDir = new File('.').canonicalFile
final def props = new Properties();
final def inputPropsFile = new File(args[0]);
final def inputPropsStream = null;
try {
    inputPropsStream = new FileInputStream(inputPropsFile);
    props.load(inputPropsStream);
}
catch (IOException e) {
    throw new RuntimeException(e);
}

def cell = props['cell']
def server = props['server']
def commandPath = (props['commandPath']!=null?props['commandPath']:"");
def node = props['node']
def user = props['user']
def password = (props['password'] != null && props['password'] != "")? props['password'] : props['passScript']
def cluster = props['cluster']

def connType = props['connType']
def host = props['host'];
def port = props['port'];
def additionalArgs = props['additionalArgs'];
def soapTimeout = props['soapTimeout'];

File tempFile = new File("temp.py")
tempFile.deleteOnExit();
File soapSettingTempFile = File.createTempFile("wsadmin_soap_props", null, workDir)
soapSettingTempFile.deleteOnExit();
File soapRedirectSettingTempFile = File.createTempFile("wsadmin_soap_redirect_props", null, workDir)
soapRedirectSettingTempFile.deleteOnExit();
BufferedWriter temp = new BufferedWriter(new FileWriter(tempFile))

if(cluster) {
  invoke = "AdminControl.invoke(AdminControl.queryNames('type=Cluster,name=" + cluster + ",*'), 'start', '')"
} else {
    if (node && node.trim().length() > 0) {
      invoke = "AdminControl.startServer('"+ server + "', '" + node + "')"
    }
    else {
      invoke = "AdminControl.startServer('"+ server + "')"
    }
}
temp.write(invoke, 0 , invoke.length())
System.out.println invoke
temp.close()

def commandArgs = [commandPath + wsadmin, "-lang", "jython"];
commandArgs << "-conntype"
commandArgs << connType.trim();

if (host) {
    commandArgs << "-host";
    commandArgs << host;
}

if (port) {
    commandArgs << "-port";
    commandArgs << port;
}

if (user) {
    commandArgs << "-user"
    commandArgs <<  user
    commandArgs << "-password"
    commandArgs << password
}

if ('SOAP' == connType.trim() && soapTimeout && soapTimeout.trim().length() > 0) {
    try {
        soapTimeout.toInteger()
        // try to find the soap client properties file
        def soapPropFileDir = new File(new File(commandPath).parentFile, 'properties')
        def soapPropFile = new File(soapPropFileDir, 'soap.client.props')
        Properties soapProps = new Properties()
        if (soapPropFile.exists()) {
            soapPropFile.withInputStream { soapProps.load(it)}
        }
        else {
            println "Warning: could not locate soap.client.properties file in $soapPropFileDir"
        }

        soapProps['com.ibm.SOAP.requestTimeout'] = soapTimeout

        soapSettingTempFile.withOutputStream {
            soapProps.save(it, 'Generated by UrbanDeploy')
            it.flush()
        }

        soapRedirectSettingTempFile.withOutputStream {
            def redirectProps = new Properties()
            redirectProps.setProperty('com.ibm.SOAP.ConfigURL', "file:${soapSettingTempFile.absolutePath}".toString())
            redirectProps.save(it, 'Generated by UrbanDeploy')
            it.flush()
        }

        commandArgs << "-p"
        commandArgs << soapRedirectSettingTempFile.name

    }
    catch (NumberFormatException nfe) {
        println "Invalid SOAP Connection Timeout value specified: $soapTimeout"
        System.exit 1
    }
}

commandArgs << "-f";
commandArgs << "temp.py";

if (additionalArgs) {
    additionalArgs.split('\n').each { arg ->
        commandArgs << arg;
    }
}

println commandArgs.join(' ');
def procBuilder = new ProcessBuilder(commandArgs);

if (isWindows) {
    def envMap = procBuilder.environment();
    envMap.put("PROFILE_CONFIG_ACTION","true");
}

def statusProc = procBuilder.start();
def outPrint = new PrintStream(out, true);
statusProc.waitForProcessOutput(outPrint, outPrint);
System.exit(statusProc.exitValue());
